.. idf-build-apps documentation master file, created by
   sphinx-quickstart on Wed Feb  8 10:04:16 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to idf-build-apps's documentation!
==========================================

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:

   find-build
   manifest
   api
   CHANGELOG
   CONTRIBUTING
